Value

Trait Value 

pub trait Value:
    Scalar
    + ComplexField<RealField = Self>
    + RealField
    + FloatCore
    + LowerExp {
Show 20 methods // Provided methods fn two() -> Self { ... } fn half() -> Self { ... } fn try_cast<U: NumCast>(n: U) -> Result<Self, Error> { ... } fn as_usize(&self) -> Option<usize> { ... } fn powi(self, n: i32) -> Self { ... } fn abs(self) -> Self { ... } fn abs_sub(self, other: Self) -> Self { ... } fn is_sign_negative(&self) -> bool { ... } fn clamp(self, min: Self, max: Self) -> Self { ... } fn min(self, other: Self) -> Self { ... } fn max(self, other: Self) -> Self { ... } fn ceil(self) -> Self { ... } fn floor(self) -> Self { ... } fn is_near_zero(&self) -> bool { ... } fn is_finite(value: Self) -> bool { ... } fn f_signum(&self) -> Self { ... } fn factorial(n: usize) -> Self { ... } fn integer_binomial(n: usize, k: usize) -> Self { ... } fn binomial(n: Self, k: Self) -> Self { ... } fn from_positive_int(n: usize) -> Self { ... }
}
Numeric type for curves

Provided Methods

fn two() -> Self

Returns the value 2.0

fn half() -> Self

Returns the value 0.5

fn try_cast<U: NumCast>(n: U) -> Result<Self, Error>

Tries to cast a value to the target type

Errors

Returns an error if the cast fails

fn as_usize(&self) -> Option<usize>

Converts the value to usize

fn powi(self, n: i32) -> Self

Raises the value to the power of an integer

fn abs(self) -> Self

Get the absolute value for a numeric type

fn abs_sub(self, other: Self) -> Self

Returns the absolute difference between two values.

fn is_sign_negative(&self) -> bool

Check if the value is negative

fn clamp(self, min: Self, max: Self) -> Self

Clamps the value between a minimum and maximum.

fn min(self, other: Self) -> Self

Returns the minimum of two values.

fn max(self, other: Self) -> Self

Returns the maximum of two values.

fn ceil(self) -> Self

Return the next value greater than self

fn floor(self) -> Self

Return the next value less than self

fn is_near_zero(&self) -> bool

Returns the machine epsilon for the numeric type.

fn is_finite(value: Self) -> bool

Checks if the value is finite (not NaN or infinite).

fn f_signum(&self) -> Self

Returns the sign of the value as a numeric type

This function returns -1 for negative values, 1 for positive values, and NaN for NaN values.

fn factorial(n: usize) -> Self

Computes the factorial of a non-negative integer n.

fn integer_binomial(n: usize, k: usize) -> Self

Computes the binomial coefficient “n choose k” for integer n and k.

fn binomial(n: Self, k: Self) -> Self

Computes the binomial coefficient “n choose k”.

fn from_positive_int(n: usize) -> Self

Converts a usize to the target numeric type.

Results in infinity if the value is out of range.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> Value for T
where T: Scalar + ComplexField<RealField = Self> + RealField + FloatCore + LowerExp,