pub struct Plot<P, T>where
P: PlotBackend,
T: Value,{ /* private fields */ }Available on crate feature
plotting only.Expand description
A plot of one or more elements (fits, functions, etc) using a given backend.
Implementations
Sourceimpl<P, T> Plot<P, T>where
P: PlotBackend,
T: Value,
impl<P, T> Plot<P, T>where
P: PlotBackend,
T: Value,
Sourcepub fn new(
root: &P::Root,
options: PlotOptions<T>,
function: &impl AsPlottingElement<T>,
) -> Result<Self, P::Error>
pub fn new( root: &P::Root, options: PlotOptions<T>, function: &impl AsPlottingElement<T>, ) -> Result<Self, P::Error>
Create a new plot with the given root, options, and primary function. The primary function is used to determine the axis ranges if they are not specified in the options.
Errors
Returns an error if the plot cannot be created.
Sourcepub fn with_element(
&mut self,
element: &impl AsPlottingElement<T>,
) -> Result<&mut Self, P::Error>
pub fn with_element( &mut self, element: &impl AsPlottingElement<T>, ) -> Result<&mut Self, P::Error>
Add another plotting element to this plot.
The element will be converted into a plotting element using the same x-values, confidence, and noise tolerance as the initial function.
Errors
Returns an error if the element cannot be added.